# Core

## Windows Setup

todo: Eventually we want this to be installed via `https://core.spikingmeurons.com/windows-setup`

This will help you get started quickly with setting `SpikingNeurons:Core` on your windows dev system.

Access gist [here](https://github.com/SpikingNeurons/Core/blob/main/.windows-setup/installer.ps1) or run the snippet below in powershell.

```powershell
$content = gh api repos/SpikingNeurons/Core/contents/.windows-setup/installer.ps1 --jq '.content' | Out-String
$decoded = [System.Text.Encoding]::UTF8.GetString([System.Convert]::FromBase64String($content.Trim()))
Invoke-Expression $decoded
```